
#[derive(Debug, serde::Serialize)]
pub struct XDatabase {
    pub data: Option<crate::Database>,
    pub children: Vec<XDataSet>
}

#[derive(Debug, serde::Serialize)]
pub struct XDataSet {
    pub data: crate::DataSet,
    pub child: XSomeList
}

#[derive(Debug, serde::Serialize)]
pub struct XTrackItem {
    pub data: crate::TrackItem,
    pub args: Vec<XArgument>
}

#[derive(Debug, serde::Serialize)]
pub struct XAlbumItem {
    pub data: crate::AlbumItem,
    pub args: Vec<XArgument>
}

#[derive(Debug, serde::Serialize)]
pub struct XPlaylist {
    pub data: crate::Playlist,
    pub args: Vec<XArgument>
}

#[derive(Debug, serde::Serialize)]
pub struct XArgument {
    pub arg_type: u32,
    pub val: String
}

#[derive(Debug, serde::Serialize)]
pub enum XSomeList {
    Playlists(Vec<XPlaylist>),
    TrackList(Vec<XTrackItem>),
    AlbumList(Vec<XAlbumItem>)
}

impl XSomeList {
    fn push_album(&mut self, album: XAlbumItem ) {
        if let XSomeList::AlbumList(albums) = self {
            albums.push(album);
        }
    }

    fn push_track(&mut self, track: XTrackItem ) {
        if let XSomeList::TrackList(tracks) = self {
            tracks.push(track);
        }
    }

    fn push_playlist(&mut self, playlist: XPlaylist ) {
        if let XSomeList::Playlists(playlists) = self {
            playlists.push(playlist);
        }
    }
}

impl XDatabase {
    pub fn find_dataset(&mut self, data_type: u32) -> &mut XDataSet {
        self.children.iter_mut().find(|d| d.data.data_type == data_type).unwrap()
    }
}